@@ -63,7 +63,6 @@ class Instrument:
 			self.midi_set = True
 			i = MidiInstrument()
 			i.instrument_nr = self.params["midi_instr"]
-			print "**** SET INSTRUMENT ****", i.names[i.instrument_nr]
 			self.track.instrument = i
 
 		if state["tick"] == 0:
@@ -74,47 +73,46 @@ class Instrument:
 			b.key = state["key"]
 			self.bar = b
 		let_ring = False
-		if 'let_ring' not in self.params:
-			self.stop_playing_notes()
+		#if 'let_ring' not in self.params:
+		self.stop_playing_notes()
+		#else:
+		#	if not self.params['let_ring']:
+		#		self.stop_playing_notes()
+		#	else:
+		#		let_ring = True
+
+
+		n = self.generate_note(state)
+		v = self.generate_velocity(state)
+		if n is not None and n != []:
+			for note in n:
+				note.velocity = int(v)
+				note.channel = self.params["channel"]
+
+			# Record played notes in a Track
+			if self.last_tick != (state["iterations"], state["tick"]):
+				self.bar.place_notes(n, state["resolution"])
+			else:
+				self.bar.bar[-1][2].add_notes(n)
+
+			if not self.no_fluidsynth:
+				fluidsynth.play_NoteContainer(n,
+					self.params["channel"], v)
+			self.last_chan = self.params["channel"]
+			self.playing += n
+			self.last_played = n
+			if state["paint_function"] != None:
+				state["paint_function"](n, self.params["channel"])
 		else:
-			if not self.params['let_ring']:
-				self.stop_playing_notes()
-			else:
-				let_ring = True
-
-
-		if 'channel' in self.params:
-			n = self.generate_note(state)
-			v = self.generate_velocity(state)
-			if n != None:
-				for note in n:
-					note.velocity = int(v)
-					note.channel = self.params["channel"]
-
-				# Record played notes in a Track
-				if self.last_tick != (state["iterations"], state["tick"]):
-					self.bar.place_notes(n, state["resolution"])
-				else:
-					self.bar.bar[-1][2].add_notes(n)
-
-				if not self.no_fluidsynth:
-					fluidsynth.play_NoteContainer(n,
-						self.params["channel"], v)
-				self.last_chan = self.params["channel"]
-				self.playing += n
-				self.last_played = n
-				if state["paint_function"] != None:
-					state["paint_function"](n, self.params["channel"])
-			else:
-				if len(self.bar) > 0:
-					if self.bar[-1][1] is None:
-						i = 1 / (1.0 / state["resolution"] + \
-							1.0 / self.bar[-1][1])
-						self.bar[-1][1] = i
-					else:
-						self.bar.place_notes(None, state["resolution"])
+			if len(self.bar) > 0:
+				if self.bar[-1][1] is None:
+					i = 1 / (1.0 / state["resolution"] + \
+						1.0 / self.bar[-1][1])
+					self.bar[-1][1] = i
 				else:
 					self.bar.place_notes(None, state["resolution"])
+			else:
+				self.bar.place_notes(None, state["resolution"])
 
 		self.last_tick = (state["iterations"], state["tick"])
 
