@@ -49,12 +49,7 @@ class Sequencer:
 		
 		if self.chord != self.state["chord"]:
 			if self.verbose:
-				if not self.no_fluidsynth:
-					if len(self.chord) != 0:
-						print chords.determine(self.chord)[0]
-					else:
-						print "Unknown chord:", self.chord
-				else:
+				if self.no_fluidsynth:
 					sys.stdout.write("|");
 			self.state["scale"] = \
 				diatonic.get_notes(self.key)
@@ -83,7 +78,7 @@ class Sequencer:
 			if self.no_fluidsynth:
 				print "|"
 			else:
-				print "-" * 20
+				print "-" * 80
 		self.iterations += 1
 		self.play_iterations -= 1
 		self.block_iteration()
@@ -110,6 +105,7 @@ class Sequencer:
 				i.end = i.start + diff
 				i.add_rest(self.state)
 			else:
+				i.stop_playing_notes()
 				i.add_rest(self.state)
 
 
